summaryrefslogtreecommitdiffstats
path: root/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake')
-rw-r--r--Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake6
1 files changed, 3 insertions, 3 deletions
diff --git a/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake b/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake
index d2c95ec..09594bd 100644
--- a/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake
+++ b/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake
@@ -6,10 +6,10 @@ add_library(empty3 INTERFACE)
target_compile_features(empty3 INTERFACE cxx_static_assert)
target_link_libraries(empty1
# When starting, $<COMPILE_FEATURES:cxx_nullptr> is '0', so 'freeze' the
# CXX_STANDARD at 98 during computation.
- $<$<COMPILE_FEATURES:cxx_nullptr>:empty2>
- # This would add cxx_constexpr, but that would require CXX_STANDARD = 11,
+ $<$<COMPILE_FEATURES:cxx_auto_type>:empty2>
+ # This would add cxx_static_assert, but that would require CXX_STANDARD = 11,
# which is not allowed after freeze. Report an error.
empty3
)
@@ -6,10 +6,10 @@ add_library(empty3 INTERFACE)
target_compile_features(empty3 INTERFACE cxx_static_assert)
target_link_libraries(empty1
- # When starting, $<COMPILE_FEATURES:cxx_nullptr> is '0', so 'freeze' the
+ # When starting, $<COMPILE_FEATURES:cxx_auto_type> is '0', so 'freeze' the
# CXX_STANDARD at 98 during computation.